DynamicAllocator

Struct DynamicAllocator 

pub struct DynamicAllocator;
A dynamically allocating Brainfuck allocator. If accessing an unallocated cell is attempted, the VM memory is expanded to be abble to support that cell.